<?php

namespace App\Http\Controllers;

use App\Appointment;
use App\Department;
use App\Doctor;
use App\Historique;
use Illuminate\Http\Request;

class AppointmentController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all appointments and pass it to the view
        $appointments = Appointment::all();

        return view('appointments.index')->with('appointments', $appointments);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $departments = Department::all();

        return view('appointments.create', compact('departments'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'firstname' => 'required',
            'email' => 'required',
            'phone_number' => 'required',
            'time_apt' => 'required',
            'date_apt' => 'required',
        ]);

        $appointment = new Appointment();
        $appointment->name = $request->input('name');
        $appointment->firstname = $request->input('firstname');
        $appointment->phone_number = $request->input('phone_number');
        $appointment->email = $request->input('email');
        $appointment->date_apt = $request->input('date_apt');
        $appointment->time_apt = $request->input('time_apt');
        $appointment->department_id = $request->input('department_id');

        $department = Department::findOrFail($appointment->department_id);

        $appointment->department_name = $department->name;

        $appointment->doctor_id = $request->input('doctor_id');

        $doctor = Doctor::findOrFail($appointment->doctor_id);

        $appointment->doctor_name = $doctor->name;
        $appointment->doctor_firstname = $doctor->firstname;
        $appointment->doctor_email = $doctor->email;
        $appointment->doctor_phone = $doctor->phone_number;
        $appointment->doctor_address = $doctor->address;
        $appointment->doctor_profession = $doctor->profession;

        $appointment->status = 0;

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Appointment';
        $historique->user_id = auth()->user()->id;

        $appointment->save();
        $historique->save();

        //Redirect to the users.index view and display message
        return redirect()->route('appointments.index')
            ->with('success',
             'Votre Rendez-vous a été enregistré avec succès.');
        
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $appointment = Appointment::findOrFail($id); //Get appointment with specified id

        return view('appointments.show', compact('appointment')); //pass appointment data to view

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $appointment = Appointment::findOrFail($id); //Get appointment with specified id

        return view('appointments.edit', compact('appointment')); //pass appointment data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $appointment = Appointment::findOrFail($id);

        $this->validate($request, [
            'name' => 'required',
            'firstname' => 'required',
            'email' => 'required',
            'phone_number' => 'required',
            'time_apt' => 'required',
            'date_apt' => 'required',
        ]);

        $appointment->name = $request->input('name');
        $appointment->firstname = $request->input('firstname');
        $appointment->phone_number = $request->input('phone_number');
        $appointment->email = $request->input('email');
        $appointment->date_apt = $request->input('date_apt');
        $appointment->time_apt = $request->input('time_apt');
        $appointment->department_id = $request->input('department_id');

        $department = Department::findOrFail($appointment->department_id);

        $appointment->department_name = $department->name;

        $appointment->doctor_id = $request->input('doctor_id');

        $doctor = Doctor::findOrFail($appointment->doctor_id);

        $appointment->doctor_name = $doctor->name;
        $appointment->doctor_firstname = $doctor->firstname;
        $appointment->doctor_email = $doctor->email;
        $appointment->doctor_phone = $doctor->phone_number;
        $appointment->doctor_address = $doctor->address;
        $appointment->doctor_profession = $doctor->profession;

        $appointment->status = 0;

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Appointment';
        $historique->user_id = auth()->user()->id;

        $appointment->save();
        $historique->save();

        //Redirect to the users.index view and display message
        return redirect()->route('appointments.index')
            ->with('success',
             'Votre Rendez-vous a été enregistré avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $appointment = Appointment::findOrFail($id); //Get appointment with specified id

        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'Appointment';
        $historique->user_id = auth()->user()->id;

        $appointment->delete();
        $historique->save();

        return redirect()->route('appointments.index')
            ->with('success',
             'Rendez-vous supprimé avec succès.');
    }
}
